import { createTestEvent } from './create-test-event';
import { Destination } from './destination-kit';
import { mapValues } from './map-values';
const noop = () => { };
class TestDestination extends Destination {
    constructor(destination) {
        super(destination);
        this.responses = [];
        this.results = [];
    }
    async testDynamicField(action, fieldKey, data, dynamicFn) {
        return await super.executeDynamicField(action, fieldKey, data, dynamicFn);
    }
    async testAction(action, { event, mapping, settings, useDefaultMappings, auth, features, statsContext, logger, dataFeedCache, transactionContext, stateContext }) {
        this.results = [];
        mapping = mapping ?? {};
        if (useDefaultMappings) {
            const fields = this.definition.actions[action].fields;
            const defaultMappings = mapValues(fields, 'default');
            mapping = { ...defaultMappings, ...mapping };
        }
        this.results = await super.executeAction(action, {
            event: createTestEvent(event),
            mapping,
            settings: settings ?? {},
            auth,
            features: features ?? {},
            statsContext: statsContext ?? {},
            logger: logger ?? { info: noop, error: noop },
            dataFeedCache: dataFeedCache ?? {},
            transactionContext: transactionContext ?? {},
            stateContext: stateContext ?? {}
        });
        const responses = this.responses;
        this.responses = [];
        return responses;
    }
    async testBatchAction(action, { events, mapping, settings, useDefaultMappings, auth, features, statsContext, logger, dataFeedCache, transactionContext, stateContext }) {
        this.results = [];
        mapping = mapping ?? {};
        if (useDefaultMappings) {
            const fields = this.definition.actions[action].fields;
            const defaultMappings = mapValues(fields, 'default');
            mapping = { ...defaultMappings, ...mapping };
        }
        if (!events || !events.length) {
            events = [{ type: 'track' }];
        }
        this.results = await super.executeBatch(action, {
            events: events.map((event) => createTestEvent(event)),
            mapping,
            settings: settings ?? {},
            auth,
            features: features ?? {},
            statsContext: statsContext ?? {},
            logger: logger ?? {},
            dataFeedCache: dataFeedCache ?? {},
            transactionContext: transactionContext ?? {},
            stateContext: stateContext ?? {}
        });
        const responses = this.responses;
        this.responses = [];
        return responses;
    }
}
export function createTestIntegration(destination) {
    return new TestDestination(destination);
}
//# sourceMappingURL=create-test-integration.js.map